Flexible Permissions is a Django app that combines object-level table permissions with model relations to avoid normalization of data while providing an extremely flexible, declarative permissions model.

Documentation is available in the wiki on the github page.